![Rust+.py](https://raw.githubusercontent.com/olijeffers0n/rustplus/master/icon.png)
<div align = "center">
	<img src = "https://lt.ollieee.xyz/rplusdownloadsbadge">
	<img src = "https://img.shields.io/pypi/v/rustplus?label=PYPI%20Version">
	<img src = "https://img.shields.io/pypi/l/rustplus">
	<img src = "https://img.shields.io/github/stars/olijeffers0n/rustplus?label=GitHub%20Stars">
	<a href = "https://discord.gg/nQqJe8qvP8">
		<img src = "https://img.shields.io/discord/872406750639321088?label=Discord">
	</a>
    <div>
        <a href = "https://ko-fi.com/O5O3ALGLJ">
            <img src= "https://ko-fi.com/img/githubbutton_sm.svg" width="190">
        </a>
    </div>
</div>

A lot of code and ideas have come from the JavaScript version of a wrapper, so I will credit it now:
[RustPlus.js](https://github.com/liamcottle/rustplus.js)
I have used their Protocol Buffer file for generating the necessary requests so chuck some support their way

## Installation:
Install the package with:
```
pip install rustplus
```
It should also install all the dependencies, but if not you will have to install them yourself

## What can you do?
- Get the Map
- Get Team Info
- Get Team Chat
- Get Server Info
- Send Team Messages
- Getting the time
- Using Smart Devices
- And so much more!

# For information on all the above methods, see the [Wiki](https://rplus.ollieee.xyz)

### Support:
If you need help, or you think that there is an issue feel free to open an issue. If you think you have made some improvements, open a PR! 

I have tried to explain this a well as possible, but if you should need further clarification, join me on my discord server:
<div align="center">
    <a href = "https://discord.gg/nQqJe8qvP8">
        <img src="https://discordapp.com/api/guilds/872406750639321088/widget.png?style=banner2" alt="Discord">
    </a>
</div>

GitHub ⭐'s are always welcome :)

Have Fun! 
